<!DOCTYPE TS><TS>
<context>
    <name>DatabaseBox</name>
    <message>
        <source>Active Play Queue</source>
        <translation>Aktiv spellista</translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Alla spellistor</translation>
    </message>
    <message>
        <source>Blechy Blech Blah</source>
        <translation>Blechy Blech Blah</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>All musik</translation>
    </message>
    <message>
        <source>All My Music ~ Loading Music Data </source>
        <translation>All musik ~ Laddar musikdata</translation>
    </message>
    <message>
        <source>Loading Music Data</source>
        <translation>Laddar musikdata</translation>
    </message>
    <message>
        <source>Move to Active Play Queue</source>
        <translation>Kopiera till aktiv spellista</translation>
    </message>
    <message>
        <source>Delete This Playlist</source>
        <translation>Radera denna spellista</translation>
    </message>
    <message>
        <source>Rename This Playlist</source>
        <translation>Döp om denna spellista</translation>
    </message>
    <message>
        <source>Copy To New Playlist</source>
        <translation>Kopiera till ny spellista</translation>
    </message>
    <message>
        <source>Clear the Active Play Queue</source>
        <translation>Rensa aktiv spellista</translation>
    </message>
    <message>
        <source>Save Back to Playlist Tree</source>
        <translation>Spara tillbaka till spellistträdet</translation>
    </message>
    <message>
        <source>The theme you are using does not contain a &apos;musictree&apos; element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation>Temat du använder innehåller inte &apos;musictree&apos;-elementet. Vänligen kontakta upphovsmannen till temat och be dem uppdatera det.

Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till menyn.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Couldn&apos;t create CD</source>
        <translation>Kunde inte skapa CD</translation>
    </message>
    <message>
        <source>CD Created</source>
        <translation>CD skapad</translation>
    </message>
    <message>
        <source>CD-RW Blanking Progress</source>
        <translation>CD-RW raderingsförlopp</translation>
    </message>
    <message>
        <source>Create Audio CD from Playlist</source>
        <translation>Skapa musik-CD från spellista</translation>
    </message>
    <message>
        <source>Create MP3 CD from Playlist</source>
        <translation>Skapa MP3-CD från spellista</translation>
    </message>
    <message>
        <source>Clear CD-RW Disk</source>
        <translation>Radera CD-RW skiva</translation>
    </message>
    <message>
        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation>Temat du använder innehåller inga informationsrader i music-elementet.&lt;br&gt;&lt;br&gt;Nästa skärm kommer att vara tom. Använd ESC för att återvända till menyn.</translation>
    </message>
    <message>
        <source>Artist:<byte value="x9"/></source>
        <translation>Artist:<byte value="x9"/></translation>
    </message>
    <message>
        <source>Album:<byte value="x9"/></source>
        <translation>Album:<byte value="x9"/></translation>
    </message>
    <message>
        <source>Title:<byte value="x9"/></source>
        <translation>Titel:<byte value="x9"/></translation>
    </message>
    <message>
        <source>Length:<byte value="x9"/></source>
        <translation>Längd:<byte value="x9"/></translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation>Genre: </translation>
    </message>
    <message>
        <source>Compilation Artist:<byte value="x9"/></source>
        <translation>Kompileringsartist:<byte value="x9"/></translation>
    </message>
</context>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Done</source>
        <translation>Klar</translation>
    </message>
    <message>
        <source>DB Statistics</source>
        <translation>DB-statistik</translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation>Blandade artister</translation>
    </message>
    <message>
        <source>Select an Artist</source>
        <translation>Välj en artist</translation>
    </message>
    <message>
        <source>Select a Compilation Artist</source>
        <translation>Välj en kompileringsartist</translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation>Välj ett album</translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation>Välj en genre</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Spara ändringar?</translation>
    </message>
    <message>
        <source>Save to Database Only</source>
        <translation>Spara endast till databas</translation>
    </message>
    <message>
        <source>Save to File Only</source>
        <translation>Spara endast till fil</translation>
    </message>
    <message>
        <source>Save to File and Database</source>
        <translation>Spara till fil och databas</translation>
    </message>
    <message>
        <source>Exit/Do Not Save</source>
        <translation>Avsluta/Spara inte</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Are you sure you want to save the modified metadata to the file?</source>
        <translation>Är du säker på att du vill spara ändrad metadata till filen?</translation>
    </message>
</context>
<context>
    <name>PlaybackBoxMusic</name>
    <message>
        <source>Edit Playlist</source>
        <translation>Redigera spellista</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation>Visualisera</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation>3 Redigera spellista</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation>4 Visualisera</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation>1 Ordning: Intelligent</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation>Ordning: Intelligent</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation>1 Ordning: Slump</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation>Ordning: Slump</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation>1 Ordning: Rak</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation>Ordning: Rak</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation>2 Repetera: Alla</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation>Repetera: Alla</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation>2 Repetera: Spår</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation>Repetera: Spår</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation>2 Repetera: Ej</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation>Repetera: Inte</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation>rot för spellistor</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation>Spelar ström.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation>Buffrar ström.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation>Ström pausad.</translation>
    </message>
    <message>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <source>kHz</source>
        <translation>kHz</translation>
    </message>
    <message>
        <source>ch</source>
        <translation>ch</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation>Utmatningsfel.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation>Ström stoppad.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation>Strömmen färdigspelad.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation>Avkodningsfel.</translation>
    </message>
    <message>
        <source>Smart playlists</source>
        <translation>Smarta spellistor</translation>
    </message>
    <message>
        <source>All Tracks</source>
        <translation>Alla spår</translation>
    </message>
    <message>
        <source>Tracks by current Artist</source>
        <translation>Spår av aktuell artist</translation>
    </message>
    <message>
        <source>Tracks from current Album</source>
        <translation>Spår från aktuellt album</translation>
    </message>
    <message>
        <source>Tracks from current Genre</source>
        <translation>Spår från aktuell genre</translation>
    </message>
    <message>
        <source>Tracks from current Year</source>
        <translation>Spår från aktuellt år</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>BumpScope</source>
        <translation>BumpScope</translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation>Blandade artister</translation>
    </message>
    <message>
        <source>Ogg Vorbis Audio</source>
        <translation>Ogg Vorbis-ljud</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>FLAC Audio</source>
        <translation>FLAC Audio</translation>
    </message>
    <message>
        <source>Directory to hold music</source>
        <translation>Katalog för musikfiler</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythMusic needs to have write permission to the directory.</source>
        <translation>Denna katalog måste finnas och användaren som kör MythMusik måste ha skrivrättigheter till den.</translation>
    </message>
    <message>
        <source>Audio device</source>
        <translation>Ljudenhet</translation>
    </message>
    <message>
        <source>Audio Device used for playback.</source>
        <translation>Ljudenhet som används för avspelning.</translation>
    </message>
    <message>
        <source>CD device</source>
        <translation>CD-enhet</translation>
    </message>
    <message>
        <source>CDRom device used for ripping/playback.</source>
        <translation>CDROM-enhet som används för kopiering/avspelning.</translation>
    </message>
    <message>
        <source>Tree Sorting</source>
        <translation>Trädsortering</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>Sökväg för skript</translation>
    </message>
    <message>
        <source>If present this script will be executed after a CD Rip is completed.</source>
        <translation>Om detta värde är satt, kommer skriptet att köras efter att en CD-kopiering är klar.</translation>
    </message>
    <message>
        <source>Filename Format</source>
        <translation>Filnamnsformat</translation>
    </message>
    <message>
        <source>Directory and filename Format used to grab information if no ID3 information is found.</source>
        <translation>Biblioteks- och filnamnsformat som används för att hämta information om ingen ID3 information hittas.</translation>
    </message>
    <message>
        <source>Ignore ID3 Tags</source>
        <translation>Ignorera ID3-information</translation>
    </message>
    <message>
        <source>If set, MythMusic will skip checking ID3 tags in files and just try to determine Genre, Artist, Album, and Track number and title from the filename.</source>
        <translation>Om funktionen är aktiverad kommer Musikspelaren inte att läsa ID3-information från filen utan försöker i stället att bestämma genre, artist, album och spårnummer från filnamnet.</translation>
    </message>
    <message>
        <source>Automatically lookup CDs</source>
        <translation>Slå upp CD-information automatiskt</translation>
    </message>
    <message>
        <source>Automatically lookup an audio CD if it is present and show its information in the Music Selection Tree.</source>
        <translation>Leta automatiskt upp information om en CD-skiva och visa informationen i trädet för musikval.</translation>
    </message>
    <message>
        <source>Use Keyboard/Remote Accelerated Buttons</source>
        <translation>Använd snabbtangenter med tangentbord/fjärrkontroll</translation>
    </message>
    <message>
        <source>If this is not set, you will need to use arrow keys to select and activate various functions.</source>
        <translation>Om denna funktion inte är aktiverad, måste piltangenterna användas för att välja diverse funktioner.</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Kodning</translation>
    </message>
    <message>
        <source>Ogg Vorbis</source>
        <translation>Ogg Vorbis</translation>
    </message>
    <message>
        <source>Lame (MP3)</source>
        <translation>Lame (MP3)</translation>
    </message>
    <message>
        <source>Audio encoder to use for CD ripping. Note that the quality level &apos;Perfect&apos; will use the FLAC encoder.</source>
        <translation>Ljudkodare att använda vid CD-kopiering. Notera att kvalitetsnivå &apos;Perfekt&apos; alltid kommer att använda kodaren &apos;FLAC&apos;.</translation>
    </message>
    <message>
        <source>File storage location</source>
        <translation>Sökväg för fillagring</translation>
    </message>
    <message>
        <source>Defines the location/name for new songs. Valid tokens are: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / and -. &apos;-&apos; will be replaced by the Token separator</source>
        <translation>Definierar sökväg/namn för nya låtar. Följande ord kommer att ersättas med sin motsvarande betydelse i det slutliga filnamnet: GENRE, ARTIST, ALBUM, TRACK (Spår), TITLE (Titel), YEAR (År). Dessutom kan &apos;/&apos; och &apos;-&apos; användas. &apos;-&apos; kommer att ersättas med den konfigurerade separatorn</translation>
    </message>
    <message>
        <source>Token separator</source>
        <translation>Separator</translation>
    </message>
    <message>
        <source> - </source>
        <translation>-</translation>
    </message>
    <message>
        <source>Filename tokens will be separated by this string.</source>
        <translation>De olika delarna av ett filnamn separeras med detta tecken.</translation>
    </message>
    <message>
        <source>Replace &apos; &apos; with &apos;_&apos;</source>
        <translation>Ersätt mellanslag med understreck</translation>
    </message>
    <message>
        <source>If set, whitespace characters in filenames will be replaced with underscore characters.</source>
        <translation>Om funktionen är aktiverad kommer mellanslagstecken att ersättas med understeck (_) i filnamn.</translation>
    </message>
    <message>
        <source>Paranoia Level</source>
        <translation>Paranoia-nivå</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Full</translation>
    </message>
    <message>
        <source>Faster</source>
        <translation>Snabbare</translation>
    </message>
    <message>
        <source>Paranoia level of the CD ripper. Set to faster if you&apos;re not concerned about possible errors in the audio.</source>
        <translation>Paranoia-nivå för CD-kopieraren. Sätt den till &apos;Snabbare&apos; om du inte är orolig för möjliga fel i det digitala ljudets bitström.</translation>
    </message>
    <message>
        <source>Automatically eject CDs after ripping</source>
        <translation>Mata ut CDn automatiskt efter kopiering</translation>
    </message>
    <message>
        <source>If set, the CD tray will automatically open after the CD has been ripped.</source>
        <translation>Om funktionen är aktiverad kommer CDn automatiskt att komma ut när den har blivit kopierad.</translation>
    </message>
    <message>
        <source>Rating Weight</source>
        <translation>Rankningsvikt</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to your rating of a given track when ordering a group of songs.</source>
        <translation>Används i &quot;Intelligent&quot; spelordningsläge. Denna viktning används för att bestämma hur stor vikt som läggs på rankningen du har gjort av en låt.</translation>
    </message>
    <message>
        <source>Play Count Weight</source>
        <translation>Viktning för antalet uppspelningar</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how many times a given track has been played when ordering a group of songs.</source>
        <translation>Används i &quot;Intelligent&quot; spelordningsläge. Denna viktning bestämmer hur stor vikt som läggs vid hur många gånger en låt har spelats.</translation>
    </message>
    <message>
        <source>Last Play Weight</source>
        <translation>Viktning för senast spelad</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how long it has been since a given track was played when ordering a group of songs.</source>
        <translation>Används i &quot;Intelligent&quot; spelordningsläge. Denna viktning bestämmer hur mycket vikt som läggs vid hur länge sedan en låt spelades.</translation>
    </message>
    <message>
        <source>Random Weight</source>
        <translation>Slumpens vikt</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to good old (peudo-)randomness when ordering a group of songs.</source>
        <translation>Används i &quot;Intelligent&quot; spelordningsläge. Denna viktning påverkar hur mycket vikt som läggs vid den framslumpade ordningen.</translation>
    </message>
    <message>
        <source>Show Song Ratings</source>
        <translation>Visa låtrankningar</translation>
    </message>
    <message>
        <source>Show song ratings on the playback screen.</source>
        <translation>Visa låtrankning i avspelningsvyn.</translation>
    </message>
    <message>
        <source>List as Shuffled</source>
        <translation>Lista låtar i spelordning</translation>
    </message>
    <message>
        <source>List songs on the playback screen in the order they will be played.</source>
        <translation>Lista låtar i avspelningsvyn i den ordning de kommer att spelas.</translation>
    </message>
    <message>
        <source>Show entire music tree</source>
        <translation>Visa hela musikträdet</translation>
    </message>
    <message>
        <source>If selected, you can navigate your entire music tree from the playing screen.</source>
        <translation>Om denna funktion är aktiverad kan hela musikträdet navigeras från avspelningsvyn. Om den inte är aktiverad syns bara färdiga spellistor.</translation>
    </message>
    <message>
        <source>Play mode</source>
        <translation>Avspelningsläge</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Slumpvis</translation>
    </message>
    <message>
        <source>Intelligent</source>
        <translation>Intelligent</translation>
    </message>
    <message>
        <source>Starting shuffle mode for the player.  Can be either normal, random, or intelligent (random).</source>
        <translation>Anger vilket avspelningsläge Musikspelaren startar i. Kan vara normal, slump eller intelligent. Se inställning för de olika vikningsparametrarna för att förstå hur det intelligenta läget fungerar.</translation>
    </message>
    <message>
        <source>Delay before Visualizations start (seconds)</source>
        <translation>Fördröjning innan visualiseringsläget startar (sekunder)</translation>
    </message>
    <message>
        <source>If set to 0, visualizations will never automatically start.</source>
        <translation>Om tiden sätts till 0 kommer visualiseringar aldrig att starta automatiskt.</translation>
    </message>
    <message>
        <source>Change Visualizer on each song</source>
        <translation>Byt visualisering efter varje låt</translation>
    </message>
    <message>
        <source>Change the visualizer when the song change.</source>
        <translation>Byt visualisering när låten byts.</translation>
    </message>
    <message>
        <source>Width for Visual Scaling</source>
        <translation>Horisontell skalningsfaktor för visualiseringar</translation>
    </message>
    <message>
        <source>If set to &quot;2&quot;, visualizations will be scaled in half.  Currently only used by the goom visualization.  Reduces CPU load on slower machines.</source>
        <translation>Om skalningsfaktorn sätts till 2 kommer visualiseringar att bli hälften så stora. Fungerar för tillfället bara med visualiseringen &apos;goom&apos;. Reducerar processorbelastningen på datorn, vilket kan vara bra på långsamma datorer.</translation>
    </message>
    <message>
        <source>Height for Visual Scaling</source>
        <translation>Vertikal skalningsfaktor för visualiseringar</translation>
    </message>
    <message>
        <source>Visualizations</source>
        <translation>Visualiseringar</translation>
    </message>
    <message>
        <source>List of visualizations to use during playback. Possible values are space-separated list of </source>
        <translation>Lista med visualiseringar som skall användas vid avspelning. Möjliga värden är en mellanslagseparerad lista av </translation>
    </message>
    <message>
        <source>MonoScope</source>
        <translation>MonoScope</translation>
    </message>
    <message>
        <source>StereoScope</source>
        <translation>StereoScope</translation>
    </message>
    <message>
        <source>Spectrum</source>
        <translation>Spectrum</translation>
    </message>
    <message>
        <source>Goom</source>
        <translation>Goom</translation>
    </message>
    <message>
        <source>Synaesthesia</source>
        <translation>Synaesthesia</translation>
    </message>
    <message>
        <source>Gears</source>
        <translation>Gears</translation>
    </message>
    <message>
        <source>Blank</source>
        <translation>Blank</translation>
    </message>
    <message>
        <source>Default Rip Quality</source>
        <translation>Kopieringskvalitet</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Låg</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hög</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfekt</translation>
    </message>
    <message>
        <source>Default quality for new CD rips.</source>
        <translation>Grundinställning för kvalitet vid CD-kopiering.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Generella inställningar</translation>
    </message>
    <message>
        <source>Playback Settings</source>
        <translation>Uppspelningsinställningar</translation>
    </message>
    <message>
        <source>Visualization Settings</source>
        <translation>Visualiseringsinställningar</translation>
    </message>
    <message>
        <source>CD Ripper Settings</source>
        <translation>Inställningar för CD-kopiering</translation>
    </message>
    <message>
        <source>MPEG Layer 1/2/3 Audio (MAD decoder)</source>
        <translation>MPEG Lager 1/2/3 Ljud (MAD dekoder)</translation>
    </message>
    <message>
        <source>Searching for music files</source>
        <translation>Letar efter musikfiler</translation>
    </message>
    <message>
        <source>Updating music database</source>
        <translation>Uppdaterar musikdatabas</translation>
    </message>
    <message>
        <source>Unknown Artist</source>
        <translation>Okänd artist</translation>
    </message>
    <message>
        <source>Unknown Album</source>
        <translation>Okänt album</translation>
    </message>
    <message>
        <source>Unknown Genre</source>
        <translation>Okänd genre</translation>
    </message>
    <message>
        <source>CD -- none</source>
        <translation>CD -- ingen</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>All musik</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <source>title</source>
        <translation>titel</translation>
    </message>
    <message>
        <source>Missing database entry: %1</source>
        <translation>Saknad databasrad: %1</translation>
    </message>
    <message>
        <source> ~ </source>
        <translation> ~ </translation>
    </message>
    <message>
        <source>Ooops</source>
        <translation>Ooops</translation>
    </message>
    <message>
        <source>%1 ~ %2</source>
        <translation>%1 ~ %2</translation>
    </message>
    <message>
        <source>Not Initialized</source>
        <translation>Ej initierad</translation>
    </message>
    <message>
        <source>oops</source>
        <translation>oops</translation>
    </message>
    <message>
        <source>,%1</source>
        <translation>,%1</translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Alla mina spellistor</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Aktiv spellista</translation>
    </message>
    <message>
        <source>Active Play Queue (%1)</source>
        <translation>Aktiv spellista (%1)</translation>
    </message>
    <message>
        <source>Something is Wrong</source>
        <translation>Något är fel</translation>
    </message>
    <message>
        <source>Visualization requires FFT library</source>
        <translation>Visualisering kräver FFT-bibliotek</translation>
    </message>
    <message>
        <source>Did you run configure?</source>
        <translation>Körde du konfigureringen?</translation>
    </message>
    <message>
        <source>and</source>
        <translation>och</translation>
    </message>
    <message>
        <source>Use variable bitrates</source>
        <translation>Använd variabel bithastighet</translation>
    </message>
    <message>
        <source>If set, the MP3 encoder will use variable bitrates (VBR) except for the low quality setting. The Ogg encoder will always use variable bitrates.</source>
        <translation>MP3-kodaren kommer att använda variabel bithastighet (VBR) förutom då lägsta kvaliteten väljs. Ogg-kodaren använder alltid variabel bithastighet.</translation>
    </message>
    <message>
        <source>AlbumArt</source>
        <translation>AlbumArt</translation>
    </message>
    <message>
        <source>CD Ripper Settings (part 2)</source>
        <translation>Inställningar för CD-kopiering (del 2)</translation>
    </message>
    <message>
        <source>Enable CD Writing.</source>
        <translation>Aktivera CD-bränning.</translation>
    </message>
    <message>
        <source>Requires a SCSI or an IDE-SCSI CD Writer.</source>
        <translation>Kräver en SCSI eller IDE-SCSI CD-brännare.</translation>
    </message>
    <message>
        <source>CD-Writer Device</source>
        <translation>CD-brännarenhet</translation>
    </message>
    <message>
        <source>Select the SCSI Device for CD Writing.  If your IDE device is not present, try adding hdd(or hdc/hdb)=ide-scsi to your boot options</source>
        <translation>Välj en SCSI-enhet för CD-bränning. Om idin IDE-enhet inte finns tillgänglig, testa lägga till hdd (eller hdc/hdb)=ide-scsi till dina startinstälningar</translation>
    </message>
    <message>
        <source>Disk Size</source>
        <translation>Skivstorlek</translation>
    </message>
    <message>
        <source>650MB/75min</source>
        <translation>650Mb/74min</translation>
    </message>
    <message>
        <source>700MB/80min</source>
        <translation>700Mb/80min</translation>
    </message>
    <message>
        <source>Default CD Capacity.</source>
        <translation>Standard CD-kapacitet.</translation>
    </message>
    <message>
        <source>Enable directories on MP3 Creation</source>
        <translation>Aktivera kataloger vid MP3-bränning</translation>
    </message>
    <message>
        <source>CD Write Speed</source>
        <translation>CD-bränningshastighet</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Audo</translation>
    </message>
    <message>
        <source>1x</source>
        <translation>1x</translation>
    </message>
    <message>
        <source>2x</source>
        <translation>2x</translation>
    </message>
    <message>
        <source>4x</source>
        <translation>4x</translation>
    </message>
    <message>
        <source>8x</source>
        <translation>8x</translation>
    </message>
    <message>
        <source>16x</source>
        <translation>16x</translation>
    </message>
    <message>
        <source>CD Writer speed. Auto will use the recomended speed.</source>
        <translation>CD-bränningshastighet. Auto använder rekommenderad hastighet.</translation>
    </message>
    <message>
        <source>CD Blanking Type</source>
        <translation>CDRW-raderingsmetod</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Snabb</translation>
    </message>
    <message>
        <source>Complete</source>
        <translation>Komplett</translation>
    </message>
    <message>
        <source>Blanking Method. Fast takes 1 minute. Complete can take up to 20 minutes.</source>
        <translation>Raderingsmetod för CDRW. Snabb tar cirka 1 minut. Komplett kan ta upp till 20 minuter.</translation>
    </message>
    <message>
        <source>CD Recording Settings</source>
        <translation>CD-bränningsinställningar</translation>
    </message>
    <message>
        <source>Artists</source>
        <translation>Artister</translation>
    </message>
    <message>
        <source>Creating CD File System</source>
        <translation>Skapar filsystem för CD</translation>
    </message>
    <message>
        <source>Burning CD</source>
        <translation>Bränner CD</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
        <translation>Den ordning som trädet för musikval sorteras i. Möjliga värden är:
* Mellanslagsseparerad lista med &apos;genre&apos;, &apos;splitartist&apos;, &apos;artist&apos;, &apos;album&apos; och &apos;title&apos;
* &apos;directory&apos; (=katalog), vilket betyder att trädet speglar den faktiska katalogstrukturen.</translation>
    </message>
    <message>
        <source>CD: %1 ~ %2 - %3</source>
        <translation>CD: %1 ~ %2 - %3</translation>
    </message>
</context>
<context>
    <name>Ripper</name>
    <message>
        <source>Please select a quality level and check the album information below:</source>
        <translation>Välj en kvalitetsnivå och kontrollera albuminformationen nedan:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Låg</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hög</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfekt</translation>
    </message>
    <message>
        <source>Artist: </source>
        <translation>Artist:</translation>
    </message>
    <message>
        <source>Album: </source>
        <translation>Album:</translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation>Genre:</translation>
    </message>
    <message>
        <source>Import this CD</source>
        <translation>Importera denna CD</translation>
    </message>
    <message>
        <source>Importing CD:
</source>
        <translation>Importing CD:
</translation>
    </message>
    <message>
        <source>Ripping...</source>
        <translation>Kopierar...</translation>
    </message>
    <message>
        <source>Copying from CD:
</source>
        <translation>Kopierar från CD:
</translation>
    </message>
    <message>
        <source>Multi-Artist?</source>
        <translation>Flera artister?</translation>
    </message>
    <message>
        <source>Switch Titles &amp;&amp; Artists</source>
        <translation>Växla Titlar &amp;&amp; Artister</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artist</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Längd</translation>
    </message>
</context>
<context>
    <name>SmartPLCriteriaRow</name>
    <message>
        <source>Select an Artist</source>
        <translation>Välj en artist</translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation>Välj ett album</translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation>Välj en genre</translation>
    </message>
    <message>
        <source>Select a Title</source>
        <translation>Välj en titel</translation>
    </message>
</context>
<context>
    <name>SmartPLOrderByDialog</name>
    <message>
        <source>Order By Fields</source>
        <translation>Sortera efter fält</translation>
    </message>
    <message>
        <source>1 Add</source>
        <translation>1 Lägg till</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <source>2 Delete</source>
        <translation>2 Radera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>3 Move Up</source>
        <translation>3 Flytta upp</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Flytta upp</translation>
    </message>
    <message>
        <source>4 Move Down</source>
        <translation>4 Flytta ned</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Flytta ned</translation>
    </message>
    <message>
        <source>5 Ascending</source>
        <translation>5 Stigande</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation>Stigande</translation>
    </message>
    <message>
        <source>6 Descending</source>
        <translation>6 Fallande</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation>Fallande</translation>
    </message>
    <message>
        <source>7 OK</source>
        <translation>7 OK</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SmartPLResultViewer</name>
    <message>
        <source>Smart Playlist Result Viewer</source>
        <translation>Smart spellistsresultatvisare</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artist</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>År</translation>
    </message>
    <message>
        <source>Track No.</source>
        <translation>Spår nr.</translation>
    </message>
</context>
<context>
    <name>SmartPlaylistDialog</name>
    <message>
        <source>Smart Playlists</source>
        <translation>Smarta spellistor</translation>
    </message>
    <message>
        <source>1 Select</source>
        <translation>1 Välj</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Välj</translation>
    </message>
    <message>
        <source>2 New</source>
        <translation>2 Ny</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>3 Edit</source>
        <translation>3 Redigera</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>4 Delete</source>
        <translation>4 Radera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this SmartPlaylist?</source>
        <translation>Är du säker på att du vill radera denna spellista?</translation>
    </message>
</context>
<context>
    <name>SmartPlaylistEditor</name>
    <message>
        <source>Smart Playlist Editor</source>
        <translation>Smart spellistseditor</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel: </translation>
    </message>
    <message>
        <source>Match</source>
        <translation>Träff</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alla</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Någon</translation>
    </message>
    <message>
        <source>Of The Following Conditions</source>
        <translation>av följande villkor</translation>
    </message>
    <message>
        <source>Order By:</source>
        <translation>Ordna efter:</translation>
    </message>
    <message>
        <source>Matches:</source>
        <translation>Träffar:</translation>
    </message>
    <message>
        <source>Limit:</source>
        <translation>Gräns:</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <source>Show Results</source>
        <translation>Visa resultat</translation>
    </message>
    <message>
        <source>Smart Playlist Categories</source>
        <translation>Smarta spellistskategorier</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Ny kategori</translation>
    </message>
    <message>
        <source>Delete Category</source>
        <translation>Radera kategori</translation>
    </message>
    <message>
        <source>Rename Category</source>
        <translation>Byt namn på kategori</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this Category?</source>
        <translation>Är du säker på att du vill radera denna kategori?</translation>
    </message>
    <message>
        <source>It will also delete any Smart Playlists belonging to this category.</source>
        <translation>Alla smarta spellistor som hör till denna kategori raderas också.</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Please Wait...</source>
        <translation>Vänta...</translation>
    </message>
    <message>
        <source>Track Information</source>
        <translation>Spårinformation</translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation>Artist: </translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Album: </translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel: </translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation>Genre: </translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>År:</translation>
    </message>
    <message>
        <source>Track No.:</source>
        <translation>Spår nr:</translation>
    </message>
    <message>
        <source>Rating:</source>
        <translation>Rankning:</translation>
    </message>
    <message>
        <source>Play Count:</source>
        <translation>Spelantal:</translation>
    </message>
    <message>
        <source>Last Play:</source>
        <translation>Senast spelad:</translation>
    </message>
    <message>
        <source>Compilation:</source>
        <translation>Kompilering:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Filnamn:</translation>
    </message>
</context>
</TS>
